VAR_INMB_DIFF: A Reference Class to represent the variance of the...

VAR_INMB_DIFFR Documentation

A Reference Class to represent the variance of the Incremental Net Monetary Benefit (INMB) when the standard deviation of costs and effectiveness in each group differ.

Description

The variance of the Incremental Net Monetary Benefit may also be calculated in a hypothetical situation when the standard deviation of costs and effectiveness in each group differ.

Fields

sdc_ref

: standard deviation of costs in the reference group

sdc_exp

: standard deviation of costs in the experimental group

sde_exp

: standard deviation of effectiveness in the experimental group

sde_ref

: standard deviation of effectiveness in the reference group

rho

: coefficient of correlation between the difference in costs (dc) and the difference in effectiveness (de)

object_lambda

: object containing the ceiling cost-effectiveness ratio or maximum acceptable cost of a unit of effectiveness. See create_object_lambda

See Also

create_object_var_inmb_direct to directly provide a value for the variance of the Incremental Net Monetary Benefit

create_object_var_inmb to calculate the theoretical standard deviation of the expected INB with the same standard deviation in the reference and the experimental group

create_object_var_inmb_diff the constructor

set_sdc_ref(sdc_ref):

sets the standard deviation of costs in the reference group of this VAR_INMB_DIFF object

set_sdc_exp(sdc_exp):

sets the standard deviation of costs in the experimental group of this VAR_INMB_DIFF object

set_sde_exp(sde_exp):

sets the standard deviation of effectiveness in the experimental group of this VAR_INMB_DIFF object

set_sde_ref(sde_ref):

sets the standard deviation of effectiveness in the reference group of this VAR_INMB_DIFF object

set_rho(rho):

Sets the coefficient of correlation between the difference in costs (dc) and the difference in effectiveness (de) of this VAR_INMB_DIFF object

set_lambda(lambda):

sets the lambda value of this VAR_INMB_DIFF object

get_var_inmb():

Return the calculated variance of the Incremental Net Monetary Benefit when the standard deviation of costs and effectiveness in each group differ.

Examples

## First, create a lambda object
object_lambda <- create_object_lambda (20000)
## Then, create a var_inmb_diff object
var_inmb_diff <- create_object_var_inmb_diff(sdc_ref=2100, sdc_exp=2100, sde_ref = 0.12,
sde_exp = 0.12, rho = 0.1,object_lambda = object_lambda)

EBASS documentation built on Sept. 4, 2026, 5:07 p.m.