create_object_inmb_direct: Create an object INMB_DIRECT

View source: R/INMB_DIRECT.R

create_object_inmb_directR Documentation

Create an object INMB_DIRECT

Description

If the INMB can be drawn from de, dc and lambda with create_object_inmb, one can also make directly an hypothesis on the value of the INMB.

Usage

create_object_inmb_direct(inmb)

Arguments

inmb

: expected Incremental Net Monetary Benefit

Value

create_object_inmb_direct returns an object of class INMB_DIRECT

See Also

create_object_inmb

Examples

## Create an object inmb_direct
object_inmb_direct <- create_object_inmb_direct (968)

EBASS documentation built on Sept. 4, 2026, 5:07 p.m.