create_object_lambda: Create an object lambda

View source: R/Lambda.R

create_object_lambdaR Documentation

Create an object lambda

Description

Lambda is known as the willingness to pay. That is the ceiling cost-effectiveness ratio or the maximum acceptable cost of a unit of effectiveness. It must be coherent with the criteria of effectiveness used in the analysis (year of life, QALY, life saved, or a criteria related to morbidity).

Usage

create_object_lambda(lambda)

Arguments

lambda

: Lambda is a monetary value. For example, the value of lambda is usually between 20 000 and 40 000 pounds/QALY in UK.

Value

create_object_lambda returns an object of class Lambda

Examples

## Create an object lambda
object_lambda <- create_object_lambda (20000)
## retrieve the lambda value from the object
object_lambda$get_lambda()

EBASS documentation built on Sept. 4, 2026, 5:07 p.m.