create_object_var_inmb_direct: Create an object var_inmb_direct

View source: R/VAR_INMB_DIRECT.R

create_object_var_inmb_directR Documentation

Create an object var_inmb_direct

Description

When absolutely no data regarding the variability of costs and effectiveness are available, it is possible to directly provide a value for the variance of the Incremental Net Monetary Benefit in this object.

Usage

create_object_var_inmb_direct(var_inmb)

Arguments

var_inmb

: variance of the Incremental Net Monetary Benefit

Value

create_object_var_inmb_direct returns an object of class VAR_INMB_DIRECT

See Also

create_object_var_inmb_diff to calculate the theoretical standard deviation of the expected INB with different standard deviation in the reference and the experimental group

create_object_var_inmb to calculate the theoretical standard deviation of the expected INB with the same standard deviation in the reference and the experimental group

Examples

## Create a var_inmb object :
object_var_inmb <- create_object_var_inmb_direct(var_inmb = 18324000)
## retrieve the inmb value from the object
object_var_inmb$get_var_inmb()

EBASS documentation built on Sept. 4, 2026, 5:07 p.m.