gamma_risk: Function to estimate the gamma risk

View source: R/fonctions_sujets.R

gamma_riskR Documentation

Function to estimate the gamma risk

Description

The gamma risk is the probability that a decision based on the expected mean of the Incremental Net Monetary Benefit (INMB) is wrong. In other terms, it is one minus the cost-effectiveness probability of an intervention. Use sample_size function first to estimate the sample size before calling this function.

Usage

gamma_risk(object_evpi_decrease)

Arguments

object_evpi_decrease

An evpi_decrease object. See create_object_evpi_decrease

Value

A numeric value representing the gamma risk (probability)


EBASS documentation built on Sept. 4, 2026, 5:07 p.m.