graph_gain_n: Plot to explain the estimated sample size calculation

View source: R/fonctions_sujets.R

graph_gain_nR Documentation

Plot to explain the estimated sample size calculation

Description

Displays a graph showing the estimated sample size based on the EVPI gain after the inclusion of new participants and the associated inclusion costs. Use sample_size first to estimate the sample size before calling this function.

Usage

graph_gain_n(object_evpi_decrease, cost_indiv)

Arguments

object_evpi_decrease

An evpi_decrease object. See create_object_evpi_decrease

cost_indiv

Mean costs induced by the inclusion and follow-up of one participant in the study

Value

'NULL', invisibly . Called for its plotting side effect.


EBASS documentation built on Sept. 4, 2026, 5:07 p.m.