View source: R/fonctions_sujets.R
| gamma_risk | R Documentation |
The gamma risk is the probability that a decision based on the expected mean of the Incremental Net Monetary Benefit (INMB) is wrong. In other terms, it is one minus the cost-effectiveness probability of an intervention. Use sample_size function first to estimate the sample size before calling this function.
gamma_risk(object_evpi_decrease)
object_evpi_decrease |
An evpi_decrease object. See create_object_evpi_decrease |
A numeric value representing the gamma risk (probability)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.