View source: R/fonctions_sujets.R
| graph_gain_n | R Documentation |
Displays a graph showing the estimated sample size based on the EVPI gain after the inclusion of new participants and the associated inclusion costs. Use sample_size first to estimate the sample size before calling this function.
graph_gain_n(object_evpi_decrease, cost_indiv)
object_evpi_decrease |
An evpi_decrease object. See create_object_evpi_decrease |
cost_indiv |
Mean costs induced by the inclusion and follow-up of one participant in the study |
'NULL', invisibly . Called for its plotting side effect.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.