View source: R/fonctions_sujets.R
| sample_size | R Documentation |
This function calculates the optimal total sample size for a planned cost-effectiveness study. The optimal sample size is reached when the marginal EVPI gain is less than or equal to the marginal cost of inclusion: (step_ref + step_exp) * cost_indiv.
sample_size(object_evpi_decrease, cost_indiv)
object_evpi_decrease |
An evpi_decrease object. See create_object_evpi_decrease |
cost_indiv |
cost of an additional inclusion in your planned cost-effectiveness study. |
A dataframe containing three columns :
N |
Total sample size of the planned cost-effectiveness study |
N_exp |
Sample size in the experimental group |
N_ref |
Sample size in the reference group |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.